# Hexagonal Sanity Check

This project checks if the dependency flow between the layers of the Hexagonal architecture defined 
for this project was respected.

### How to configure

First it's necessary to define your hexagonal layers and their order.

### Generating the Project Diagram

To generate the Hexagonal Diagram of the project, it's necessary to have Graphviz installed in the machine.  
For Mac you can ``brew install graphviz``.  
For other, check the documentation https://graphviz.org/download/. 

